=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2006-06-25 21:04:37 +0000
+++ bzrlib/repository.py	2006-07-04 17:23:00 +0000
@@ -466,8 +466,14 @@
     def get_revision_graph(self, revision_id=None):
         """Return a dictionary containing the revision graph.
         
+        :param revision_id: The revision_id to get a graph from. If None, then
+        the entire revision graph is returned. This is a deprecated mode of
+        operation and will be removed in the future.
         :return: a dictionary of revision_id->revision_parents_list.
         """
+        # special case NULL_REVISION
+        if revision_id == NULL_REVISION:
+            return {}
         weave = self.get_inventory_weave()
         all_revisions = self._eliminate_revisions_not_present(weave.versions())
         entire_graph = dict([(node, weave.get_parents(node)) for 
@@ -501,7 +507,10 @@
             required = set([])
         else:
             pending = set(revision_ids)
-            required = set(revision_ids)
+            # special case NULL_REVISION
+            if NULL_REVISION in pending:
+                pending.remove(NULL_REVISION)
+            required = set(pending)
         done = set([])
         while len(pending):
             revision_id = pending.pop()
@@ -873,9 +882,15 @@
     @needs_read_lock
     def get_revision_graph(self, revision_id=None):
         """Return a dictionary containing the revision graph.
-        
+
+        :param revision_id: The revision_id to get a graph from. If None, then
+        the entire revision graph is returned. This is a deprecated mode of
+        operation and will be removed in the future.
         :return: a dictionary of revision_id->revision_parents_list.
         """
+        # special case NULL_REVISION
+        if revision_id == NULL_REVISION:
+            return {}
         weave = self._get_revision_vf()
         entire_graph = weave.get_graph()
         if revision_id is None:
@@ -909,7 +924,10 @@
             required = set([])
         else:
             pending = set(revision_ids)
-            required = set(revision_ids)
+            # special case NULL_REVISION
+            if NULL_REVISION in pending:
+                pending.remove(NULL_REVISION)
+            required = set(pending)
         done = set([])
         while len(pending):
             revision_id = pending.pop()

=== modified file 'bzrlib/revision.py'
--- bzrlib/revision.py	2006-06-20 03:57:11 +0000
+++ bzrlib/revision.py	2006-07-04 17:23:00 +0000
@@ -240,6 +240,8 @@
                     pb=DummyProgress()):
     if None in (revision_a, revision_b):
         return None
+    if NULL_REVISION in (revision_a, revision_b):
+        return NULL_REVISION
     # trivial optimisation
     if revision_a == revision_b:
         return revision_a

=== modified file 'bzrlib/tests/branch_implementations/test_branch.py'
--- bzrlib/tests/branch_implementations/test_branch.py	2006-06-22 15:42:26 +0000
+++ bzrlib/tests/branch_implementations/test_branch.py	2006-07-04 17:23:00 +0000
@@ -29,6 +29,7 @@
                            NotBranchError,
                            )
 from bzrlib.osutils import getcwd
+import bzrlib.revision
 from bzrlib.tests import TestCase, TestCaseWithTransport, TestSkipped
 from bzrlib.tests.bzrdir_implementations.test_bzrdir import TestCaseWithBzrDir
 from bzrlib.trace import mutter
@@ -358,6 +359,12 @@
         tree.branch.generate_revision_history(rev1)
         self.assertEqual(orig_history, tree.branch.revision_history())
 
+    def test_generate_revision_history_NULL_REVISION(self):
+        tree = self.make_branch_and_tree('.')
+        rev1 = tree.commit('foo')
+        tree.branch.generate_revision_history(bzrlib.revision.NULL_REVISION)
+        self.assertEqual([], tree.branch.revision_history())
+
 
 class ChrootedTests(TestCaseWithBranch):
     """A support class that provides readonly urls outside the local namespace.

=== modified file 'bzrlib/tests/repository_implementations/test_repository.py'
--- bzrlib/tests/repository_implementations/test_repository.py	2006-06-25 21:04:37 +0000
+++ bzrlib/tests/repository_implementations/test_repository.py	2006-07-04 17:23:00 +0000
@@ -388,6 +388,9 @@
                           'rev3':['rev2'],
                           },
                          self.bzrdir.open_repository().get_revision_graph('rev3'))
+        # and we can ask for the NULLREVISION graph
+        self.assertEqual({},
+            self.bzrdir.open_repository().get_revision_graph(NULL_REVISION))
 
     def test_get_revision_graph_with_ghosts(self):
         # we can get a graph object with roots, ghosts, ancestors and
@@ -410,6 +413,10 @@
                           'rev4':{},
                           },
                           graph.get_descendants())
+        # and we can ask for the NULLREVISION graph
+        graph = repo.get_revision_graph_with_ghosts([NULL_REVISION])
+        self.assertEqual({}, graph.get_ancestors())
+        self.assertEqual({}, graph.get_descendants())
 
 
 class TestCaseWithCorruptRepository(TestCaseWithRepository):

=== modified file 'bzrlib/tests/test_revision.py'
--- bzrlib/tests/test_revision.py	2006-06-20 03:57:11 +0000
+++ bzrlib/tests/test_revision.py	2006-07-04 17:23:00 +0000
@@ -23,7 +23,8 @@
 from bzrlib.graph import Graph
 from bzrlib.revision import (find_present_ancestors, combined_graph,
                              common_ancestor,
-                             is_ancestor, MultipleRevisionSources)
+                             is_ancestor, MultipleRevisionSources,
+                             NULL_REVISION)
 from bzrlib.tests import TestCaseWithTransport
 from bzrlib.trace import mutter
 from bzrlib.workingtree import WorkingTree
@@ -221,6 +222,12 @@
         self.assertTrue(common_ancestor(revisions_2[6], revisions[5], sources),
                         (revisions[4], revisions_2[5]))
         self.assertEqual(None, common_ancestor(None, revisions[5], sources))
+        self.assertEqual(NULL_REVISION,
+            common_ancestor(NULL_REVISION, NULL_REVISION, sources))
+        self.assertEqual(NULL_REVISION,
+            common_ancestor(revisions[0], NULL_REVISION, sources))
+        self.assertEqual(NULL_REVISION,
+            common_ancestor(NULL_REVISION, revisions[0], sources))
 
     def test_combined(self):
         """combined_graph

